@@ -20,8 +20,9 @@
 
 
 import hamcrest
+from hamcrest.core.matcher import Matcher
 from hamcrest.core.base_matcher import BaseMatcher
-from hamcrest import assert_that, is_
+from hamcrest import is_, instance_of
 
 from .internal import (
     Method, InvocationContext, ANY_ARG, MockBase, SpyBase,
@@ -31,7 +32,7 @@ __all__ = ['called',
            'never',
            'verify', 'any_order_verify',
            'property_got', 'property_set',
-           'assert_that', 'is_']
+           'assert_that', 'is_', 'instance_of']
 
 
 # just hamcrest aliases
@@ -40,6 +41,16 @@ at_most = hamcrest.less_than_or_equal_to
 any_time = hamcrest.greater_than(0)
 
 
+class MatcherRequiredError(Exception):
+    pass
+
+
+def assert_that(actual, matcher=None, reason=''):
+    if matcher and not isinstance(matcher, Matcher):
+        raise MatcherRequiredError("%s should be a hamcrest Matcher" % str(matcher))
+    return hamcrest.assert_that(actual, matcher, reason)
+
+
 class OperationMatcher(BaseMatcher):
     pass
 
@@ -69,7 +80,7 @@ class MethodCalled(OperationMatcher):
 
     def describe_to(self, description):
         description.append_text('these calls:\n')
-        description.append_text(self.method.show(indent=10))
+        description.append_text(self.method._show(indent=10))
         description.append_text(str(self.context))
         if self._times != any_time:
             description.append_text(' -- times: %s' % self._times)
@@ -82,6 +93,11 @@ class MethodCalled(OperationMatcher):
         self.context.update_args(args, kargs)
         return self
 
+    def with_some_args(self, **kargs):
+        self.context.update_args(tuple(), kargs)
+        self.context.check_some_args = True
+        return self
+
     def async(self, timeout):
         self._async_timeout = timeout
         return self
@@ -127,7 +143,7 @@ class MockIsExpectedInvocation(BaseMatcher):
 
     def describe_mismatch(self, actual, description):
         description.append_text("this call was not expected:\n")
-        description.append_text(self.invocation.show(indent=10))
+        description.append_text(self.invocation._show(indent=10))
 
 
 class verify(BaseMatcher):
@@ -168,11 +184,12 @@ class property_got(OperationMatcher):
             self.operation, 1, cmp_pred=Invocation.__eq__)
 
     def times(self, n):
-        return property_got(self.property_name, n)
+        self._times = n
+        return self
 
     def describe_to(self, description):
         description.append_text('these calls:\n')
-        description.append_text(self.operation.show(indent=10))
+        description.append_text(self.operation._show(indent=10))
         if self._times != any_time:
             description.append_text(' -- times: %s' % self._times)
 
@@ -195,14 +212,16 @@ class property_set(OperationMatcher):
             self.operation, self._times, cmp_pred=Invocation.__eq__)
 
     def to(self, value):
-        return property_set(self.property_name, value)
+        self.value = value
+        return self
 
     def times(self, n):
-        return property_set(self.property_name, self.value, n)
+        self._times = n
+        return self
 
     def describe_to(self, description):
         description.append_text('these calls:\n')
-        description.append_text(self.operation.show(indent=10))
+        description.append_text(self.operation._show(indent=10))
         if self._times != any_time:
             description.append_text(' -- times: %s' % self._times)
 
